@@ -123,6 +123,7 @@ $ENV{flag_initial} and $FAI::reinstall = 0;
 #
 ################################################################################
 %FAI::current_lvm_config = ();
+$FAI::uses_lvm = 0;
 
 ################################################################################
 #
@@ -130,6 +131,7 @@ $ENV{flag_initial} and $FAI::reinstall = 0;
 #
 ################################################################################
 %FAI::current_raid_config = ();
+$FAI::uses_raid = 0;
 
 ################################################################################
 #
